@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.3';
+our $VERSION = '1.9.5';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -1488,7 +1488,16 @@ sub attributes {
             default => '',
         },
         samlIDPMetaDataOptionsSLOBinding => {
-            type => 'text',
+            type   => 'select',
+            select => [
+                { k => '',              v => '' },
+                { k => 'http-post',     v => 'POST' },
+                { k => 'http-redirect', v => 'Redirect' },
+                { k => 'http-soap',     v => 'SOAP' },
+                { k => 'artifact-get',  v => 'Artifact GET' },
+                { k => 'artifact-post', v => 'Artifact POST' },
+            ],
+            default => '',
         },
         samlIDPMetaDataOptionsEncryptionMode => {
             type   => 'select',
@@ -1631,6 +1640,10 @@ sub attributes {
             type    => 'bool',
             default => 0,
         },
+        samlSPMetaDataOptionsForceUTF8 => {
+            type    => 'bool',
+            default => 1,
+        },
 
         # AUTH, USERDB and PASSWORD MODULES
         authentication => {
